==> psi-plugins-debug-1.5-3-x86_64.pkg.tar.zst: usr/src/debug/psi-plugins/plugins-1.5/generic/birthdayreminderplugin/.rcc/qrc_birthdayreminderplugin.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.15.14
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /build/psi-plugins/src/plugins-1.5/generic/birthdayreminderplugin/birthday.png
  0x0,0x0,0x3,0x64,
  0x89,
  0x50,0x4e,0x47,0xd,0xa,0x1a,0xa,0x0,0x0,0x0,0xd,0x49,0x48,0x44,0x52,0x0,
  0x0,0x0,0x10,0x0,0x0,0x0,0x10,0x8,0x6,0x0,0x0,0x0,0x1f,0xf3,0xff,0x61,
  0x0,0x0,0x0,0x6,0x62,0x4b,0x47,0x44,0x0,0xfe,0x0,0xfe,0x0,0xfe,0xeb,0x18,
  0xd4,0x82,0x0,0x0,0x0,0x9,0x70,0x48,0x59,0x73,0x0,0x0,0x0,0x48,0x0,0x0,
  0x0,0x48,0x0,0x46,0xc9,0x6b,0x3e,0x0,0x0,0x0,0x9,0x76,0x70,0x41,0x67,0x0,
  0x0,0x0,0x10,0x0,0x0,0x0,0x10,0x0,0x5c,0xc6,0xad,0xc3,0x0,0x0,0x2,0x8d,
  0x49,0x44,0x41,0x54,0x38,0xcb,0x85,0x93,0x4d,0x48,0x94,0x51,0x14,0x86,0x9f,0x3b,
  0xdf,0xcc,0xd4,0x8c,0x8e,0x3,0x36,0x8e,0xa6,0x62,0x45,0x11,0xf6,0x63,0x11,0x5,
  0x95,0xd5,0x46,0xa8,0x96,0x82,0x20,0x91,0xd4,0xaa,0x56,0xd1,0xaa,0x76,0x41,0x44,
  0xb5,0xa,0x6a,0xd1,0x46,0x49,0xb2,0x1f,0xa1,0x4d,0xb4,0xa8,0x4d,0x41,0xd1,0x44,
  0x44,0x98,0x19,0x28,0x25,0x54,0x46,0x33,0xa6,0x39,0x33,0xe6,0xcf,0xe7,0xcc,0x7c,
  0xfa,0xcd,0x7c,0x3f,0xf7,0xb6,0xa8,0x49,0xad,0xac,0xb3,0x3a,0xe7,0xf0,0x9e,0x7,
  0xde,0x97,0x7b,0x5,0x4b,0x54,0xea,0xc2,0xd9,0x68,0xde,0x9c,0x5b,0x2d,0x1d,0x57,
  0x2d,0x53,0x2a,0x5e,0x7b,0xf9,0xea,0xd4,0xdf,0x74,0xe2,0xf7,0x45,0xf6,0x56,0x57,
  0x28,0x3d,0xfa,0xe5,0x78,0xe2,0xc9,0xe3,0x23,0x41,0xa8,0xb6,0xd,0x83,0x8c,0x3e,
  0x35,0x56,0xbd,0x7b,0x5f,0xe7,0xba,0xb5,0x6b,0xba,0x57,0x5c,0xbc,0x94,0x5f,0xa8,
  0xf7,0x2e,0x1c,0x72,0x37,0x3a,0xbd,0x1f,0xfb,0xfb,0xaf,0x2c,0xb3,0xf2,0xc7,0xf6,
  0x1f,0x3a,0x2c,0x90,0x20,0x52,0xa3,0x18,0x83,0xef,0x2a,0xfb,0x7b,0x7b,0xda,0x5f,
  0x65,0xb2,0x1b,0x80,0x53,0x80,0x2a,0xde,0x68,0xb,0x1,0x47,0xeb,0x6a,0xda,0x84,
  0x61,0x9c,0x6b,0x68,0x69,0xf5,0x8a,0x9d,0x7b,0x84,0x58,0x5f,0x2f,0x28,0x29,0xc3,
  0x9f,0xcd,0xb0,0x32,0x33,0x2d,0xd2,0x9f,0x3f,0x6d,0x6f,0x5a,0x5f,0x9f,0xb8,0x3f,
  0x96,0x7c,0x5b,0xbc,0xf1,0x14,0x9b,0x37,0x6d,0xad,0xda,0xf0,0xf3,0xe7,0xa7,0xeb,
  0xab,0x57,0x7a,0x29,0xaf,0x80,0x8a,0x4a,0x88,0x44,0x51,0xd1,0x2a,0x41,0xb8,0x1c,
  0xbf,0x2f,0x40,0x43,0x69,0x89,0xcf,0x33,0x1a,0x3f,0x5,0x84,0xff,0xb0,0xb0,0x7c,
  0x38,0x51,0x17,0xb4,0xa,0x5b,0x7c,0xe9,0x34,0xc,0x7d,0x50,0xb8,0xae,0x0,0x85,
  0x18,0x19,0x51,0x64,0x74,0xf0,0x7a,0x59,0xa1,0x69,0x54,0xf9,0xfd,0x5b,0x9b,0x34,
  0x36,0xc7,0x5c,0x5e,0x2e,0x2,0xd8,0x96,0xbd,0x39,0x8c,0x14,0x8c,0x7e,0x81,0xd7,
  0x3d,0x90,0x48,0xfc,0xf0,0x99,0xd1,0x21,0x99,0x2,0xa5,0x40,0x68,0x84,0x3c,0x9a,
  0x68,0x2c,0x2b,0xdd,0x14,0xd3,0x8d,0x5e,0xc0,0x99,0x7,0xd8,0x56,0x30,0x28,0x15,
  0x4c,0xeb,0x90,0x88,0xc3,0xb7,0x49,0x50,0xa0,0x2c,0xb,0x5c,0xb,0xe1,0x4a,0xd0,
  0x3c,0xf8,0x0,0xbf,0xa6,0x5,0x80,0x0,0x90,0x9b,0xb7,0x80,0x4a,0xe6,0x6c,0x7,
  0x6c,0x1b,0xc,0x43,0xe0,0x4a,0x85,0xc7,0x23,0x4,0x28,0xa4,0x4,0x24,0x48,0x29,
  0x4c,0x94,0x4a,0x9a,0x85,0xc9,0x62,0x7e,0xbf,0x42,0x2c,0x59,0xbd,0x66,0x60,0x46,
  0x29,0xc3,0x41,0x42,0xc1,0x54,0x38,0x36,0x48,0xa9,0x70,0x1c,0x70,0x6c,0x28,0x98,
  0x58,0x28,0xa5,0x4b,0x95,0xbd,0x39,0x97,0x1f,0x6,0xec,0x45,0x80,0xb5,0xf,0x1e,
  0xe5,0x9c,0x40,0xe0,0xee,0xb8,0xcf,0x7,0x56,0x1,0xe6,0x72,0x60,0xce,0x42,0xc1,
  0x4,0x23,0xb,0x56,0x81,0x94,0xc7,0xcb,0x98,0xa6,0x3d,0x2c,0x28,0xe6,0x0,0x73,
  0x11,0x0,0x60,0x5b,0xe3,0xde,0xb,0x7d,0x13,0xfa,0xf8,0x74,0x28,0x4,0x8e,0x3,
  0xb9,0xc,0x18,0x19,0xc0,0x65,0x22,0x54,0x46,0xdf,0xf4,0x54,0xfa,0x8e,0x6e,0x74,
  0x3,0x53,0xc5,0xc7,0xb4,0x8,0x50,0xdb,0x75,0x7b,0xa4,0xe6,0xe0,0x81,0xb6,0xa7,
  0x89,0xc4,0xe7,0xf7,0x7e,0x9f,0xfa,0x5a,0x11,0xe5,0x6b,0x24,0xca,0x20,0x9a,0x8a,
  0xc5,0xe3,0x43,0x3d,0xe5,0x95,0x67,0x5e,0xe8,0x33,0x49,0x20,0xb5,0xe4,0x5f,0x0,
  0xb8,0xb6,0x6b,0xc7,0x46,0x99,0x1e,0x3b,0x2f,0x66,0xcd,0x16,0x0,0xe9,0xf5,0xdc,
  0xbf,0x67,0xda,0xd7,0x63,0x33,0xb9,0x11,0x60,0x18,0x98,0xfd,0x27,0x0,0xa0,0xab,
  0xaa,0xfc,0x99,0x2d,0xe5,0x2a,0x29,0x55,0x18,0x84,0x7d,0x62,0x72,0x66,0x27,0x90,
  0x2c,0x86,0xf7,0x5f,0xc0,0xcf,0x8a,0x36,0x37,0x37,0x9f,0x74,0x5d,0xb7,0x31,0x10,
  0x8,0xc4,0x23,0x91,0x48,0x7b,0x47,0x47,0xc7,0xc0,0x42,0xc1,0x77,0xd9,0x9f,0x2e,
  0x40,0xe7,0x5b,0x4,0x9,0x0,0x0,0x0,0x25,0x74,0x45,0x58,0x74,0x63,0x72,0x65,
  0x61,0x74,0x65,0x2d,0x64,0x61,0x74,0x65,0x0,0x32,0x30,0x31,0x30,0x2d,0x30,0x31,
  0x2d,0x30,0x34,0x54,0x30,0x39,0x3a,0x34,0x31,0x3a,0x30,0x39,0x2b,0x30,0x32,0x3a,
  0x30,0x30,0xfd,0x8e,0x17,0xd9,0x0,0x0,0x0,0x25,0x74,0x45,0x58,0x74,0x6d,0x6f,
  0x64,0x69,0x66,0x79,0x2d,0x64,0x61,0x74,0x65,0x0,0x32,0x30,0x31,0x30,0x2d,0x30,
  0x31,0x2d,0x30,0x34,0x54,0x30,0x39,0x3a,0x34,0x31,0x3a,0x30,0x39,0x2b,0x30,0x32,
  0x3a,0x30,0x30,0xa2,0x3f,0x61,0xed,0x0,0x0,0x0,0x0,0x49,0x45,0x4e,0x44,0xae,
  0x42,0x60,0x82,
  
};

static const unsigned char qt_resource_name[] = {
  // reminder
  0x0,0x8,
  0xc,0x40,0x45,0xc2,
  0x0,0x72,
  0x0,0x65,0x0,0x6d,0x0,0x69,0x0,0x6e,0x0,0x64,0x0,0x65,0x0,0x72,
    // birthday.png
  0x0,0xc,
  0x7,0xad,0x62,0x87,
  0x0,0x62,
  0x0,0x69,0x0,0x72,0x0,0x74,0x0,0x68,0x0,0x64,0x0,0x61,0x0,0x79,0x0,0x2e,0x0,0x70,0x0,0x6e,0x0,0x67,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x90,0xad,0x1,0xb2,0x80,
  // :/reminder
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x90,0xad,0x1,0xb2,0x80,
  // :/reminder/birthday.png
  0x0,0x0,0x0,0x16,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x90,0xad,0x1,0xb2,0x80,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_birthdayreminderplugin)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_birthdayreminderplugin)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_birthdayreminderplugin)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_birthdayreminderplugin)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_birthdayreminderplugin)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_birthdayreminderplugin)(); }
   } dummy;
}

==> psi-plugins-debug-1.5-3.1-x86_64.pkg.tar.zst: usr/src/debug/psi-plugins/plugins-1.5/generic/birthdayreminderplugin/.rcc/qrc_birthdayreminderplugin.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.15.14
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /startdir/src/plugins-1.5/generic/birthdayreminderplugin/birthday.png
  0x0,0x0,0x3,0x64,
  0x89,
  0x50,0x4e,0x47,0xd,0xa,0x1a,0xa,0x0,0x0,0x0,0xd,0x49,0x48,0x44,0x52,0x0,
  0x0,0x0,0x10,0x0,0x0,0x0,0x10,0x8,0x6,0x0,0x0,0x0,0x1f,0xf3,0xff,0x61,
  0x0,0x0,0x0,0x6,0x62,0x4b,0x47,0x44,0x0,0xfe,0x0,0xfe,0x0,0xfe,0xeb,0x18,
  0xd4,0x82,0x0,0x0,0x0,0x9,0x70,0x48,0x59,0x73,0x0,0x0,0x0,0x48,0x0,0x0,
  0x0,0x48,0x0,0x46,0xc9,0x6b,0x3e,0x0,0x0,0x0,0x9,0x76,0x70,0x41,0x67,0x0,
  0x0,0x0,0x10,0x0,0x0,0x0,0x10,0x0,0x5c,0xc6,0xad,0xc3,0x0,0x0,0x2,0x8d,
  0x49,0x44,0x41,0x54,0x38,0xcb,0x85,0x93,0x4d,0x48,0x94,0x51,0x14,0x86,0x9f,0x3b,
  0xdf,0xcc,0xd4,0x8c,0x8e,0x3,0x36,0x8e,0xa6,0x62,0x45,0x11,0xf6,0x63,0x11,0x5,
  0x95,0xd5,0x46,0xa8,0x96,0x82,0x20,0x91,0xd4,0xaa,0x56,0xd1,0xaa,0x76,0x41,0x44,
  0xb5,0xa,0x6a,0xd1,0x46,0x49,0xb2,0x1f,0xa1,0x4d,0xb4,0xa8,0x4d,0x41,0xd1,0x44,
  0x44,0x98,0x19,0x28,0x25,0x54,0x46,0x33,0xa6,0x39,0x33,0xe6,0xcf,0xe7,0xcc,0x7c,
  0xfa,0xcd,0x7c,0x3f,0xf7,0xb6,0xa8,0x49,0xad,0xac,0xb3,0x3a,0xe7,0xf0,0x9e,0x7,
  0xde,0x97,0x7b,0x5,0x4b,0x54,0xea,0xc2,0xd9,0x68,0xde,0x9c,0x5b,0x2d,0x1d,0x57,
  0x2d,0x53,0x2a,0x5e,0x7b,0xf9,0xea,0xd4,0xdf,0x74,0xe2,0xf7,0x45,0xf6,0x56,0x57,
  0x28,0x3d,0xfa,0xe5,0x78,0xe2,0xc9,0xe3,0x23,0x41,0xa8,0xb6,0xd,0x83,0x8c,0x3e,
  0x35,0x56,0xbd,0x7b,0x5f,0xe7,0xba,0xb5,0x6b,0xba,0x57,0x5c,0xbc,0x94,0x5f,0xa8,
  0xf7,0x2e,0x1c,0x72,0x37,0x3a,0xbd,0x1f,0xfb,0xfb,0xaf,0x2c,0xb3,0xf2,0xc7,0xf6,
  0x1f,0x3a,0x2c,0x90,0x20,0x52,0xa3,0x18,0x83,0xef,0x2a,0xfb,0x7b,0x7b,0xda,0x5f,
  0x65,0xb2,0x1b,0x80,0x53,0x80,0x2a,0xde,0x68,0xb,0x1,0x47,0xeb,0x6a,0xda,0x84,
  0x61,0x9c,0x6b,0x68,0x69,0xf5,0x8a,0x9d,0x7b,0x84,0x58,0x5f,0x2f,0x28,0x29,0xc3,
  0x9f,0xcd,0xb0,0x32,0x33,0x2d,0xd2,0x9f,0x3f,0x6d,0x6f,0x5a,0x5f,0x9f,0xb8,0x3f,
  0x96,0x7c,0x5b,0xbc,0xf1,0x14,0x9b,0x37,0x6d,0xad,0xda,0xf0,0xf3,0xe7,0xa7,0xeb,
  0xab,0x57,0x7a,0x29,0xaf,0x80,0x8a,0x4a,0x88,0x44,0x51,0xd1,0x2a,0x41,0xb8,0x1c,
  0xbf,0x2f,0x40,0x43,0x69,0x89,0xcf,0x33,0x1a,0x3f,0x5,0x84,0xff,0xb0,0xb0,0x7c,
  0x38,0x51,0x17,0xb4,0xa,0x5b,0x7c,0xe9,0x34,0xc,0x7d,0x50,0xb8,0xae,0x0,0x85,
  0x18,0x19,0x51,0x64,0x74,0xf0,0x7a,0x59,0xa1,0x69,0x54,0xf9,0xfd,0x5b,0x9b,0x34,
  0x36,0xc7,0x5c,0x5e,0x2e,0x2,0xd8,0x96,0xbd,0x39,0x8c,0x14,0x8c,0x7e,0x81,0xd7,
  0x3d,0x90,0x48,0xfc,0xf0,0x99,0xd1,0x21,0x99,0x2,0xa5,0x40,0x68,0x84,0x3c,0x9a,
  0x68,0x2c,0x2b,0xdd,0x14,0xd3,0x8d,0x5e,0xc0,0x99,0x7,0xd8,0x56,0x30,0x28,0x15,
  0x4c,0xeb,0x90,0x88,0xc3,0xb7,0x49,0x50,0xa0,0x2c,0xb,0x5c,0xb,0xe1,0x4a,0xd0,
  0x3c,0xf8,0x0,0xbf,0xa6,0x5,0x80,0x0,0x90,0x9b,0xb7,0x80,0x4a,0xe6,0x6c,0x7,
  0x6c,0x1b,0xc,0x43,0xe0,0x4a,0x85,0xc7,0x23,0x4,0x28,0xa4,0x4,0x24,0x48,0x29,
  0x4c,0x94,0x4a,0x9a,0x85,0xc9,0x62,0x7e,0xbf,0x42,0x2c,0x59,0xbd,0x66,0x60,0x46,
  0x29,0xc3,0x41,0x42,0xc1,0x54,0x38,0x36,0x48,0xa9,0x70,0x1c,0x70,0x6c,0x28,0x98,
  0x58,0x28,0xa5,0x4b,0x95,0xbd,0x39,0x97,0x1f,0x6,0xec,0x45,0x80,0xb5,0xf,0x1e,
  0xe5,0x9c,0x40,0xe0,0xee,0xb8,0xcf,0x7,0x56,0x1,0xe6,0x72,0x60,0xce,0x42,0xc1,
  0x4,0x23,0xb,0x56,0x81,0x94,0xc7,0xcb,0x98,0xa6,0x3d,0x2c,0x28,0xe6,0x0,0x73,
  0x11,0x0,0x60,0x5b,0xe3,0xde,0xb,0x7d,0x13,0xfa,0xf8,0x74,0x28,0x4,0x8e,0x3,
  0xb9,0xc,0x18,0x19,0xc0,0x65,0x22,0x54,0x46,0xdf,0xf4,0x54,0xfa,0x8e,0x6e,0x74,
  0x3,0x53,0xc5,0xc7,0xb4,0x8,0x50,0xdb,0x75,0x7b,0xa4,0xe6,0xe0,0x81,0xb6,0xa7,
  0x89,0xc4,0xe7,0xf7,0x7e,0x9f,0xfa,0x5a,0x11,0xe5,0x6b,0x24,0xca,0x20,0x9a,0x8a,
  0xc5,0xe3,0x43,0x3d,0xe5,0x95,0x67,0x5e,0xe8,0x33,0x49,0x20,0xb5,0xe4,0x5f,0x0,
  0xb8,0xb6,0x6b,0xc7,0x46,0x99,0x1e,0x3b,0x2f,0x66,0xcd,0x16,0x0,0xe9,0xf5,0xdc,
  0xbf,0x67,0xda,0xd7,0x63,0x33,0xb9,0x11,0x60,0x18,0x98,0xfd,0x27,0x0,0xa0,0xab,
  0xaa,0xfc,0x99,0x2d,0xe5,0x2a,0x29,0x55,0x18,0x84,0x7d,0x62,0x72,0x66,0x27,0x90,
  0x2c,0x86,0xf7,0x5f,0xc0,0xcf,0x8a,0x36,0x37,0x37,0x9f,0x74,0x5d,0xb7,0x31,0x10,
  0x8,0xc4,0x23,0x91,0x48,0x7b,0x47,0x47,0xc7,0xc0,0x42,0xc1,0x77,0xd9,0x9f,0x2e,
  0x40,0xe7,0x5b,0x4,0x9,0x0,0x0,0x0,0x25,0x74,0x45,0x58,0x74,0x63,0x72,0x65,
  0x61,0x74,0x65,0x2d,0x64,0x61,0x74,0x65,0x0,0x32,0x30,0x31,0x30,0x2d,0x30,0x31,
  0x2d,0x30,0x34,0x54,0x30,0x39,0x3a,0x34,0x31,0x3a,0x30,0x39,0x2b,0x30,0x32,0x3a,
  0x30,0x30,0xfd,0x8e,0x17,0xd9,0x0,0x0,0x0,0x25,0x74,0x45,0x58,0x74,0x6d,0x6f,
  0x64,0x69,0x66,0x79,0x2d,0x64,0x61,0x74,0x65,0x0,0x32,0x30,0x31,0x30,0x2d,0x30,
  0x31,0x2d,0x30,0x34,0x54,0x30,0x39,0x3a,0x34,0x31,0x3a,0x30,0x39,0x2b,0x30,0x32,
  0x3a,0x30,0x30,0xa2,0x3f,0x61,0xed,0x0,0x0,0x0,0x0,0x49,0x45,0x4e,0x44,0xae,
  0x42,0x60,0x82,
  
};

static const unsigned char qt_resource_name[] = {
  // reminder
  0x0,0x8,
  0xc,0x40,0x45,0xc2,
  0x0,0x72,
  0x0,0x65,0x0,0x6d,0x0,0x69,0x0,0x6e,0x0,0x64,0x0,0x65,0x0,0x72,
    // birthday.png
  0x0,0xc,
  0x7,0xad,0x62,0x87,
  0x0,0x62,
  0x0,0x69,0x0,0x72,0x0,0x74,0x0,0x68,0x0,0x64,0x0,0x61,0x0,0x79,0x0,0x2e,0x0,0x70,0x0,0x6e,0x0,0x67,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x90,0xad,0x23,0x5b,0xb0,
  // :/reminder
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x90,0xad,0x23,0x5b,0xb0,
  // :/reminder/birthday.png
  0x0,0x0,0x0,0x16,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x90,0xad,0x23,0x5b,0xb0,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_birthdayreminderplugin)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_birthdayreminderplugin)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_birthdayreminderplugin)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_birthdayreminderplugin)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_birthdayreminderplugin)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_birthdayreminderplugin)(); }
   } dummy;
}
